@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _TV_SETTINGS_H_
-#define _TV_SETTINGS_H_
+#ifndef TV_SETTINGS_H
+#define TV_SETTINGS_H
 
 #include "filesettingsbase.h"
 
@@ -31,9 +31,9 @@ public:
 
 	virtual bool existSettingsFor(QString filename);
 
-	virtual void loadSettingsFor(QString filename, MediaSettings & mset);
+	virtual void loadSettingsFor(QString filename, MediaSettings & mset, int player);
 
-	virtual void saveSettingsFor(QString filename, MediaSettings & mset);
+	virtual void saveSettingsFor(QString filename, MediaSettings & mset, int player);
 
 	static QString filenameToGroupname(const QString & filename);
 
